# Form implementation generated from reading ui file 'sway_input_config/ui/error_message.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_ErrorMessage(object):
    def setupUi(self, ErrorMessage):
        ErrorMessage.setObjectName("ErrorMessage")
        ErrorMessage.setWindowModality(QtCore.Qt.WindowModality.WindowModal)
        ErrorMessage.resize(670, 115)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(ErrorMessage.sizePolicy().hasHeightForWidth())
        ErrorMessage.setSizePolicy(sizePolicy)
        ErrorMessage.setMinimumSize(QtCore.QSize(670, 115))
        ErrorMessage.setMaximumSize(QtCore.QSize(670, 115))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("sway_input_config/ui/../data/logo_sic.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        ErrorMessage.setWindowIcon(icon)
        self.verticalLayout = QtWidgets.QVBoxLayout(ErrorMessage)
        self.verticalLayout.setObjectName("verticalLayout")
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(parent=ErrorMessage)
        self.label.setTextFormat(QtCore.Qt.TextFormat.AutoText)
        self.label.setWordWrap(True)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.verticalLayout.addLayout(self.horizontalLayout)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout.addItem(spacerItem1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=ErrorMessage)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.horizontalLayout_3.addWidget(self.buttonBox)
        self.verticalLayout.addLayout(self.horizontalLayout_3)

        self.retranslateUi(ErrorMessage)
        QtCore.QMetaObject.connectSlotsByName(ErrorMessage)

    def retranslateUi(self, ErrorMessage):
        _translate = QtCore.QCoreApplication.translate
        ErrorMessage.setWindowTitle(_translate("ErrorMessage", "Sway socket not found!"))
        self.label.setText(_translate("ErrorMessage", "<html><head/><body><p><span style=\" font-size:10pt;\">Sway Input Configurator only supports Sway. You are probably using an unsupported window manager or there are problems with your Sway configuration.</span></p></body></html>"))
