# Form implementation generated from reading ui file 'sway_input_config/ui/selectlayout.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_SelectKeyboardLayoutDialog(object):
    def setupUi(self, SelectKeyboardLayoutDialog):
        SelectKeyboardLayoutDialog.setObjectName("SelectKeyboardLayoutDialog")
        SelectKeyboardLayoutDialog.resize(520, 480)
        SelectKeyboardLayoutDialog.setMinimumSize(QtCore.QSize(520, 480))
        SelectKeyboardLayoutDialog.setMaximumSize(QtCore.QSize(520, 480))
        SelectKeyboardLayoutDialog.setLocale(QtCore.QLocale(QtCore.QLocale.Language.English, QtCore.QLocale.Country.UnitedStates))
        self.gridLayout = QtWidgets.QGridLayout(SelectKeyboardLayoutDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(parent=SelectKeyboardLayoutDialog)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(parent=SelectKeyboardLayoutDialog)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 0, 2, 1, 1)
        self.layouts = QtWidgets.QListWidget(parent=SelectKeyboardLayoutDialog)
        self.layouts.setObjectName("layouts")
        self.gridLayout.addWidget(self.layouts, 1, 0, 1, 2)
        self.variants = QtWidgets.QListWidget(parent=SelectKeyboardLayoutDialog)
        self.variants.setObjectName("variants")
        self.gridLayout.addWidget(self.variants, 1, 2, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=SelectKeyboardLayoutDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 2, 0, 1, 3)

        self.retranslateUi(SelectKeyboardLayoutDialog)
        QtCore.QMetaObject.connectSlotsByName(SelectKeyboardLayoutDialog)

    def retranslateUi(self, SelectKeyboardLayoutDialog):
        _translate = QtCore.QCoreApplication.translate
        SelectKeyboardLayoutDialog.setWindowTitle(_translate("SelectKeyboardLayoutDialog", "Select a keyboard layout"))
        self.label.setText(_translate("SelectKeyboardLayoutDialog", "Language"))
        self.label_2.setText(_translate("SelectKeyboardLayoutDialog", "Variant"))
        self.layouts.setSortingEnabled(True)
